#!/bin/sh
#======================================================================
# macOS shell script to launch Template Processor (Generator)
# with FlexDoc/XML DiagramKit as provider of diagrams
#======================================================================

#----------------------------------------------------------------------
# Specify the absolute pathname of FlexDoc/XML home directory
# (by default, derive it from the location of this shell script file)
#----------------------------------------------------------------------
FDH=`cd "$(dirname "${BASH_SOURCE[0]}")/../.." > /dev/null && pwd`

#----------------------------------------------------------------------
# Specify the command used to invoke JVM (Java 11 or later) here.
# The default setting:
#
# JAVA_COMMAND="$FDH/jre/bin/java"
#
# assumes the installation of FlexDoc JRE (OpenJDK+JavaFX),
# which you can download from http://www.flexdoc.xyz/downloads/
#----------------------------------------------------------------------
JAVA_COMMAND="$FDH/jre/bin/java"

#----------------------------------------------------------------------
# Specify the location of JavaFX SDK 'lib' directory, e.g.:
# /Users/Shared/javafx-sdk-16/lib
#
# Note: When you use FlexDoc JRE, leave this setting empty
#----------------------------------------------------------------------
PATH_TO_FX=
   
#----------------------------------------------------------------------
# -Xmx option sets the maximum heap size allocated by JVM.
#
# Check this option when you need to process large quantities of data!
#
# Note that allocating too much memory isn't good either because it may actually
# decrease the performance, especially when that amount of memory isn't backed
# by the physical RAM on your system.
#
# The JVM options below set the initial Java heap size to 2048 Mb
# and allow extending it up to 4096 Mb.
#----------------------------------------------------------------------
JAVA_OPTIONS="-Xms2048m -Xmx4096m"

#----------------------------------------------------------------------
# FlexDoc/XML module path
#----------------------------------------------------------------------
MODULE_PATH="$FDH/lib/flexdoc-xml.jar:$FDH/lib/flexdoc-xml-diagramkit.jar:$FDH/lib/xercesImpl.jar:$PATH_TO_FX"

#----------------------------------------------------------------------
# Run generator with all settings taken from generator.config file
# (found in '{flexdoc-xml}/config' directory).
#
# The '-flexdocconfig' option specifies the FlexDoc main configuration
# file prepared for macOS (found in '{flexdoc-xml}/bin/macOS' directory).
#
# The '-m:IMAGE_PROVIDER' option specifies FlexDoc/XML DiagramKit as element image provider.
#
# Other double quotes are needed also because of possible spaces in file pathnames.
#----------------------------------------------------------------------

"$JAVA_COMMAND" $JAVA_OPTIONS --module-path "$MODULE_PATH" --module flexdoc.xml/xyz.flexdoc.xml.Generator \
    -flexdocconfig "$FDH/bin/macOS/flexdoc.config" \
    -m:IMAGE_PROVIDER=DiagramKit